Documentation
¶
Overview ¶
Load balancers control how requests are distributed among multiple endpoints.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LoadBalancer ¶
type LoadBalancer interface {
// This function will be called each time locaiton would need to choose the next endpoint for the request
NextEndpoint(req Request) (Endpoint, error)
// Load balancer can intercept the request
Middleware
// Load balancer may observe the request stats to get some runtime metrics
Observer
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Dynamic weighted round robin load balancer
|
Dynamic weighted round robin load balancer |
Click to show internal directories.
Click to hide internal directories.